@@ -5,6 +5,10 @@ use warnings;
 
 use base qw(HTML::Widgets::NavMenu::Iterator::NavMenu);
 
+__PACKAGE__->mk_accessors(qw(
+    _was_role
+));
+
 =head1 NAME
 
 HTML::Widgets::NavMenu::Iterator::NavMenu::HeaderRole - a nav-menu iterator
@@ -19,15 +23,36 @@ default behaviour with all others.
 
 =cut
 
+sub _start_handle_non_role
+{
+    my $self = shift;
+
+    if ($self->_was_role())
+    {
+        $self->_add_tags(
+            $self->gen_ul_tag({'depth' => $self->stack->len()-2})
+        );
+    }
+
+    $self->_was_role(0);
+
+    return $self->SUPER::_start_handle_non_role();
+}
+
 sub _start_handle_role
 {
     my $self = shift;
     if ($self->get_role() eq "header")
     {
+        if (! $self->_was_role())
+        {
+            $self->_add_tags("</ul>");
+        }
         $self->_add_tags(
-            "</ul>","<h2>", $self->get_link_tag(), "</h2>",
-            $self->gen_ul_tag('depth' => $self->stack->len()-1)
+            "<h2>", $self->get_link_tag(), "</h2>",
             );
+
+        $self->_was_role(1);
     }
     else
     {
